# -*- coding: utf-8 -*-
#-----------------------------------------------------------------------------
# Copyright (c) 2011, Evan Leis
#
# Distributed under the terms of the Lesser GNU General Public License (LGPL)
#-----------------------------------------------------------------------------
from kayako.api import KayakoAPI
from kayako.core.lib import UnsetParameter, FOREVER
from kayako.objects import *

__NAME__ = 'kayako'
__VERSION__ = '1.0.03'
__AUTHOR__ = 'Evan Leis'
__EMAIL__ = 'engineergod@yahoo.com'
